@@ -52,10 +52,10 @@ public:
 		fromExtras(fromExtras_){}
 
     bool startElement(const QString &namespaceURI, const QString &localName,
-                      const QString &qName, const QXmlAttributes &attributes) Q_DECL_OVERRIDE;
+                      const QString &qName, const QXmlAttributes &attributes) override;
     bool endElement(const QString &namespaceURI, const QString &localName,
-                    const QString &qName) Q_DECL_OVERRIDE;
-    bool characters(const QString &str) Q_DECL_OVERRIDE;
+                    const QString &qName) override;
+    bool characters(const QString &str) override;
 //    bool fatalError(const QXmlParseException &exception);
 //    QString errorString() const;
 
@@ -162,7 +162,7 @@ QString Rules::getRulesName()
 		return name;
 	}
 
-	return QString::null;
+    return {};
 }
 
 QString Rules::findXkbDir()
